public inbox for stable@vger.kernel.org
 help / color / mirror / Atom feed
From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: stable@vger.kernel.org
Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	patches@lists.linux.dev, stable <stable@kernel.org>,
	Guan-Yu Lin <guanyulin@google.com>,
	Hailong Liu <hailong.liu@oppo.com>,
	Mathias Nyman <mathias.nyman@linux.intel.com>
Subject: [PATCH 6.19 247/311] usb: core: use dedicated spinlock for offload state
Date: Wed,  8 Apr 2026 20:04:07 +0200	[thread overview]
Message-ID: <20260408175948.614635883@linuxfoundation.org> (raw)
In-Reply-To: <20260408175939.393281918@linuxfoundation.org>

6.19-stable review patch.  If anyone has any objections, please let me know.

------------------

From: Guan-Yu Lin <guanyulin@google.com>

commit bd3d245b0fef571f93504904df62b8865b1c0d34 upstream.

Replace the coarse USB device lock with a dedicated offload_lock
spinlock to reduce contention during offload operations. Use
offload_pm_locked to synchronize with PM transitions and replace
the legacy offload_at_suspend flag.

Optimize usb_offload_get/put by switching from auto-resume/suspend
to pm_runtime_get_if_active(). This ensures offload state is only
modified when the device is already active, avoiding unnecessary
power transitions.

Cc: stable <stable@kernel.org>
Fixes: ef82a4803aab ("xhci: sideband: add api to trace sideband usage")
Signed-off-by: Guan-Yu Lin <guanyulin@google.com>
Tested-by: Hailong Liu <hailong.liu@oppo.com>
Acked-by: Mathias Nyman <mathias.nyman@linux.intel.com>
Link: https://patch.msgid.link/20260401123238.3790062-2-guanyulin@google.com
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
 drivers/usb/core/driver.c        |   23 +++++---
 drivers/usb/core/offload.c       |  102 ++++++++++++++++++++++-----------------
 drivers/usb/core/usb.c           |    1 
 drivers/usb/host/xhci-sideband.c |    4 -
 include/linux/usb.h              |   10 +++
 5 files changed, 84 insertions(+), 56 deletions(-)

--- a/drivers/usb/core/driver.c
+++ b/drivers/usb/core/driver.c
@@ -1415,14 +1415,16 @@ static int usb_suspend_both(struct usb_d
 	int			status = 0;
 	int			i = 0, n = 0;
 	struct usb_interface	*intf;
+	bool			offload_active = false;
 
 	if (udev->state == USB_STATE_NOTATTACHED ||
 			udev->state == USB_STATE_SUSPENDED)
 		goto done;
 
+	usb_offload_set_pm_locked(udev, true);
 	if (msg.event == PM_EVENT_SUSPEND && usb_offload_check(udev)) {
 		dev_dbg(&udev->dev, "device offloaded, skip suspend.\n");
-		udev->offload_at_suspend = 1;
+		offload_active = true;
 	}
 
 	/* Suspend all the interfaces and then udev itself */
@@ -1436,8 +1438,7 @@ static int usb_suspend_both(struct usb_d
 			 * interrupt urbs, allowing interrupt events to be
 			 * handled during system suspend.
 			 */
-			if (udev->offload_at_suspend &&
-			    intf->needs_remote_wakeup) {
+			if (offload_active && intf->needs_remote_wakeup) {
 				dev_dbg(&intf->dev,
 					"device offloaded, skip suspend.\n");
 				continue;
@@ -1452,7 +1453,7 @@ static int usb_suspend_both(struct usb_d
 		}
 	}
 	if (status == 0) {
-		if (!udev->offload_at_suspend)
+		if (!offload_active)
 			status = usb_suspend_device(udev, msg);
 
 		/*
@@ -1498,7 +1499,7 @@ static int usb_suspend_both(struct usb_d
 	 */
 	} else {
 		udev->can_submit = 0;
-		if (!udev->offload_at_suspend) {
+		if (!offload_active) {
 			for (i = 0; i < 16; ++i) {
 				usb_hcd_flush_endpoint(udev, udev->ep_out[i]);
 				usb_hcd_flush_endpoint(udev, udev->ep_in[i]);
@@ -1507,6 +1508,8 @@ static int usb_suspend_both(struct usb_d
 	}
 
  done:
+	if (status != 0)
+		usb_offload_set_pm_locked(udev, false);
 	dev_vdbg(&udev->dev, "%s: status %d\n", __func__, status);
 	return status;
 }
@@ -1536,16 +1539,19 @@ static int usb_resume_both(struct usb_de
 	int			status = 0;
 	int			i;
 	struct usb_interface	*intf;
+	bool			offload_active = false;
 
 	if (udev->state == USB_STATE_NOTATTACHED) {
 		status = -ENODEV;
 		goto done;
 	}
 	udev->can_submit = 1;
+	if (msg.event == PM_EVENT_RESUME)
+		offload_active = usb_offload_check(udev);
 
 	/* Resume the device */
 	if (udev->state == USB_STATE_SUSPENDED || udev->reset_resume) {
-		if (!udev->offload_at_suspend)
+		if (!offload_active)
 			status = usb_resume_device(udev, msg);
 		else
 			dev_dbg(&udev->dev,
@@ -1562,8 +1568,7 @@ static int usb_resume_both(struct usb_de
 			 * pending interrupt urbs, allowing interrupt events
 			 * to be handled during system suspend.
 			 */
-			if (udev->offload_at_suspend &&
-			    intf->needs_remote_wakeup) {
+			if (offload_active && intf->needs_remote_wakeup) {
 				dev_dbg(&intf->dev,
 					"device offloaded, skip resume.\n");
 				continue;
@@ -1572,11 +1577,11 @@ static int usb_resume_both(struct usb_de
 					udev->reset_resume);
 		}
 	}
-	udev->offload_at_suspend = 0;
 	usb_mark_last_busy(udev);
 
  done:
 	dev_vdbg(&udev->dev, "%s: status %d\n", __func__, status);
+	usb_offload_set_pm_locked(udev, false);
 	if (!status)
 		udev->reset_resume = 0;
 	return status;
--- a/drivers/usb/core/usb.c
+++ b/drivers/usb/core/usb.c
@@ -671,6 +671,7 @@ struct usb_device *usb_alloc_dev(struct
 	set_dev_node(&dev->dev, dev_to_node(bus->sysdev));
 	dev->state = USB_STATE_ATTACHED;
 	dev->lpm_disable_count = 1;
+	spin_lock_init(&dev->offload_lock);
 	dev->offload_usage = 0;
 	atomic_set(&dev->urbnum, 0);
 
--- a/drivers/usb/host/xhci-sideband.c
+++ b/drivers/usb/host/xhci-sideband.c
@@ -285,8 +285,8 @@ EXPORT_SYMBOL_GPL(xhci_sideband_get_even
  * Allow other drivers, such as usb controller driver, to check if there are
  * any sideband activity on the host controller. This information could be used
  * for power management or other forms of resource management. The caller should
- * ensure downstream usb devices are all either suspended or marked as
- * "offload_at_suspend" to ensure the correctness of the return value.
+ * ensure downstream usb devices are all marked as "offload_pm_locked" to ensure
+ * the correctness of the return value.
  *
  * Returns true on any active sideband existence, false otherwise.
  */
--- a/include/linux/usb.h
+++ b/include/linux/usb.h
@@ -21,6 +21,7 @@
 #include <linux/completion.h>	/* for struct completion */
 #include <linux/sched.h>	/* for current && schedule_timeout */
 #include <linux/mutex.h>	/* for struct mutex */
+#include <linux/spinlock.h>	/* for spinlock_t */
 #include <linux/pm_runtime.h>	/* for runtime PM */
 
 struct usb_device;
@@ -636,8 +637,9 @@ struct usb3_lpm_parameters {
  * @do_remote_wakeup:  remote wakeup should be enabled
  * @reset_resume: needs reset instead of resume
  * @port_is_suspended: the upstream port is suspended (L2 or U3)
- * @offload_at_suspend: offload activities during suspend is enabled.
+ * @offload_pm_locked: prevents offload_usage changes during PM transitions.
  * @offload_usage: number of offload activities happening on this usb device.
+ * @offload_lock: protects offload_usage and offload_pm_locked
  * @slot_id: Slot ID assigned by xHCI
  * @l1_params: best effor service latency for USB2 L1 LPM state, and L1 timeout.
  * @u1_params: exit latencies for USB3 U1 LPM state, and hub-initiated timeout.
@@ -726,8 +728,9 @@ struct usb_device {
 	unsigned do_remote_wakeup:1;
 	unsigned reset_resume:1;
 	unsigned port_is_suspended:1;
-	unsigned offload_at_suspend:1;
+	unsigned offload_pm_locked:1;
 	int offload_usage;
+	spinlock_t offload_lock;
 	enum usb_link_tunnel_mode tunnel_mode;
 	struct device_link *usb4_link;
 
@@ -849,6 +852,7 @@ static inline void usb_mark_last_busy(st
 int usb_offload_get(struct usb_device *udev);
 int usb_offload_put(struct usb_device *udev);
 bool usb_offload_check(struct usb_device *udev);
+void usb_offload_set_pm_locked(struct usb_device *udev, bool locked);
 #else
 
 static inline int usb_offload_get(struct usb_device *udev)
@@ -857,6 +861,8 @@ static inline int usb_offload_put(struct
 { return 0; }
 static inline bool usb_offload_check(struct usb_device *udev)
 { return false; }
+static inline void usb_offload_set_pm_locked(struct usb_device *udev, bool locked)
+{ }
 #endif
 
 extern int usb_disable_lpm(struct usb_device *udev);



  parent reply	other threads:[~2026-04-08 19:01 UTC|newest]

Thread overview: 320+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-04-08 18:00 [PATCH 6.19 000/311] 6.19.12-rc1 review Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 001/311] drm/amd/pm: disable OD_FAN_CURVE if temp or pwm range invalid for smu v13 Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 002/311] net: correctly handle tunneled traffic on IPV6_CSUM GSO fallback Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 003/311] net: mana: fix use-after-free in add_adev() error path Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 004/311] scsi: target: file: Use kzalloc_flex for aio_cmd Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 005/311] scsi: target: tcm_loop: Drain commands in target_reset handler Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 006/311] xfs: factor out xfs_attr3_node_entry_remove Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 007/311] xfs: factor out xfs_attr3_leaf_init Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 008/311] xfs: close crash window in attr dabtree inactivation Greg Kroah-Hartman
2026-04-09  1:14   ` Long Li
2026-04-08 18:00 ` [PATCH 6.19 009/311] arm64/scs: Fix handling of advance_loc4 Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 010/311] HID: logitech-hidpp: Enable MX Master 4 over bluetooth Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 011/311] wifi: mac80211: check tdls flag in ieee80211_tdls_oper Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 012/311] HID: wacom: fix out-of-bounds read in wacom_intuos_bt_irq Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 013/311] atm: lec: fix use-after-free in sock_def_readable() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 014/311] btrfs: dont take device_list_mutex when querying zone info Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 015/311] tg3: replace placeholder MAC address with device property Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 016/311] objtool: Fix Clang jump table detection Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 017/311] HID: logitech-hidpp: Prevent use-after-free on force feedback initialisation failure Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 018/311] HID: core: Mitigate potential OOB by removing bogus memset() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 019/311] objtool/klp: fix mkstemp() failure with long paths Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 020/311] HID: multitouch: Check to ensure report responses match the request Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 021/311] btrfs: reserve enough transaction items for qgroup ioctls Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 022/311] i2c: tegra: Dont mark devices with pins as IRQ safe Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 023/311] btrfs: reject root items with drop_progress and zero drop_level Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 024/311] drm/amd/display: Fix gamma 2.2 colorop TFs Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 025/311] smb: client: fix generic/694 due to wrong ->i_blocks Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 026/311] spi: geni-qcom: Check DMA interrupts early in ISR Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 027/311] mshv: Fix error handling in mshv_region_pin Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 028/311] dt-bindings: auxdisplay: ht16k33: Use unevaluatedProperties to fix common property warning Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 029/311] wifi: iwlwifi: mld: Fix MLO scan timing Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 030/311] wifi: iwlwifi: mvm: dont send a 6E related command when not supported Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 031/311] wifi: iwlwifi: mld: correctly set wifi generation data Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 032/311] wifi: ath11k: Pass the correct value of each TID during a stop AMPDU session Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 033/311] cgroup: Wait for dying tasks to leave on rmdir Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 034/311] selftests/cgroup: Dont require synchronous populated update on task exit Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 035/311] cgroup: Fix cgroup_drain_dying() testing the wrong condition Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 036/311] crypto: caam - fix DMA corruption on long hmac keys Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 037/311] crypto: caam - fix overflow " Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 038/311] crypto: deflate - fix spurious -ENOSPC Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 039/311] crypto: af-alg - fix NULL pointer dereference in scatterwalk Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 040/311] mpls: add seqcount to protect the platform_label{,s} pair Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 041/311] net: mana: Fix RX skb truesize accounting Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 042/311] netdevsim: fix build if SKB_EXTENSIONS=n Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 043/311] net: fec: fix the PTP periodic output sysfs interface Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 044/311] net: enetc: reset PIR and CIR if they are not equal when initializing TX ring Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 045/311] net: enetc: add graceful stop to safely reinitialize the TX Ring Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 046/311] net: enetc: do not access non-existent registers on pseudo MAC Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 047/311] net: qrtr: replace qrtr_tx_flow radix_tree with xarray to fix memory leak Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 048/311] net: ipv6: ndisc: fix ndisc_ra_useropt to initialize nduseropt_padX fields to zero to prevent an info-leak Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 049/311] iommupt/amdv1: mark amdv1pt_install_leaf_entry as __always_inline Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 050/311] net/ipv6: ioam6: prevent schema length wraparound in trace fill Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 051/311] tg3: Fix race for querying speed/duplex Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 052/311] net: ti: icssg-prueth: fix missing data copy and wrong recycle in ZC RX dispatch Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 053/311] ipv6: icmp: clear skb2->cb[] in ip6_err_gen_icmpv6_unreach() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 054/311] ip6_tunnel: clear skb2->cb[] in ip4ip6_err() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 055/311] eth: fbnic: Account for page fragments when updating BDQ tail Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 056/311] bridge: br_nd_send: linearize skb before parsing ND options Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 057/311] net/sched: sch_hfsc: fix divide-by-zero in rtsc_min() Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 058/311] net: sfp: Fix Ubiquiti U-Fiber Instant SFP module on mvneta Greg Kroah-Hartman
2026-04-08 18:00 ` [PATCH 6.19 059/311] net: enetc: check whether the RSS algorithm is Toeplitz Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 060/311] net: enetc: do not allow VF to configure the RSS key Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 061/311] ALSA: usb-audio: Exclude Scarlett Solo 1st Gen from SKIP_IFACE_SETUP Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 062/311] ASoC: ep93xx: Fix unchecked clk_prepare_enable() and add rollback on failure Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 063/311] ipv6: prevent possible UaF in addrconf_permanent_addr() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 064/311] net: airoha: Add missing cleanup bits in airoha_qdma_cleanup_rx_queue() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 065/311] net: introduce mangleid_features Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 066/311] net: use skb_header_pointer() for TCPv4 GSO frag_off check Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 067/311] net: sched: cls_api: fix tc_chain_fill_node to initialize tcm_info to zero to prevent an info-leak Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 068/311] bnxt_en: set backing store type from query type Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 069/311] crypto: algif_aead - Revert to operating out-of-place Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 070/311] crypto: authencesn - Do not place hiseq at end of dst for out-of-place decryption Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 071/311] net: bonding: fix use-after-free in bond_xmit_broadcast() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 072/311] NFC: pn533: bound the UART receive buffer Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 073/311] net: xilinx: axienet: Correct BD length masks to match AXIDMA IP spec Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 074/311] net: xilinx: axienet: Fix BQL accounting for multi-BD TX packets Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 075/311] ASoC: Intel: boards: fix unmet dependency on PINCTRL Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 076/311] bridge: mrp: reject zero test interval to avoid OOM panic Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 077/311] bpf: Fix regsafe() for pointers to packet Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 078/311] net: ipv6: flowlabel: defer exclusive option free until RCU teardown Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 079/311] mptcp: add eat_recv_skb helper Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 080/311] mptcp: fix soft lockup in mptcp_recvmsg() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 081/311] net: stmmac: skip VLAN restore when VLAN hash ops are missing Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 082/311] ALSA: usb-audio: Exclude Scarlett 2i2 1st Gen (8016) from SKIP_IFACE_SETUP Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 083/311] netfilter: flowtable: strictly check for maximum number of actions Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 084/311] netfilter: nfnetlink_log: account for netlink header size Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 085/311] netfilter: x_tables: ensure names are nul-terminated Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 086/311] netfilter: ipset: use nla_strcmp for IPSET_ATTR_NAME attr Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 087/311] netfilter: nf_conntrack_helper: pass helper to expect cleanup Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 088/311] netfilter: ctnetlink: zero expect NAT fields when CTA_EXPECT_NAT absent Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 089/311] netfilter: nf_conntrack_expect: honor expectation helper field Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 090/311] netfilter: nf_conntrack_expect: use expect->helper Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 091/311] netfilter: nf_conntrack_expect: store netns and zone in expectation Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 092/311] netfilter: ctnetlink: ignore explicit helper on new expectations Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 093/311] netfilter: x_tables: restrict xt_check_match/xt_check_target extensions for NFPROTO_ARP Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 094/311] netfilter: nf_tables: reject immediate NF_QUEUE verdict Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 095/311] Bluetooth: hci_sync: call destroy in hci_cmd_sync_run if immediate Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 096/311] Bluetooth: SCO: fix race conditions in sco_sock_connect() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 097/311] Bluetooth: L2CAP: Add support for setting BT_PHY Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 098/311] Bluetooth: hci_sync: hci_cmd_sync_queue_once() return -EEXIST if exists Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 099/311] Bluetooth: hci_sync: fix leaks when hci_cmd_sync_queue_once fails Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 100/311] Bluetooth: hci_sync: Fix UAF in le_read_features_complete Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 101/311] Bluetooth: hci_h4: Fix race during initialization Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 102/311] Bluetooth: MGMT: validate LTK enc_size on load Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 103/311] Bluetooth: hci_conn: fix potential UAF in set_cig_params_sync Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 104/311] Bluetooth: hci_event: fix potential UAF in hci_le_remote_conn_param_req_evt Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 105/311] Bluetooth: MGMT: validate mesh send advertising payload length Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 106/311] rds: ib: reject FRMR registration before IB connection is established Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 107/311] bpf: sockmap: Fix use-after-free of sk->sk_socket in sk_psock_verdict_data_ready() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 108/311] net/sched: sch_netem: fix out-of-bounds access in packet corruption Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 109/311] net: macb: fix clk handling on PCI glue driver removal Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 110/311] net: macb: properly unregister fixed rate clocks Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 111/311] net/mlx5: lag: Check for LAG device before creating debugfs Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 112/311] net/mlx5: Avoid "No data available" when FW version queries fail Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 113/311] net/mlx5: Fix switchdev mode rollback in case of failure Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 114/311] bnxt_en: Refactor some basic ring setup and adjustment logic Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 115/311] bnxt_en: Dont assume XDP is never enabled in bnxt_init_dflt_ring_mode() Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 116/311] bnxt_en: Restore default stat ctxs for ULP when resource is available Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 117/311] net/x25: Fix potential double free of skb Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 118/311] net/x25: Fix overflow when accumulating packets Greg Kroah-Hartman
2026-04-08 18:01 ` [PATCH 6.19 119/311] net/sched: cls_fw: fix NULL pointer dereference on shared blocks Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 120/311] net/sched: cls_flow: " Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 121/311] net: hsr: fix VLAN add unwind on slave errors Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 122/311] ipv6: avoid overflows in ip6_datagram_send_ctl() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 123/311] eth: fbnic: Increase FBNIC_QUEUE_SIZE_MIN to 64 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 124/311] bpf: reject direct access to nullable PTR_TO_BUF pointers Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 125/311] bpf: Reject sleepable kprobe_multi programs at attach time Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 126/311] bpf: Fix incorrect pruning due to atomic fetch precision tracking Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 127/311] Revert "drm: Fix use-after-free on framebuffers and property blobs when calling drm_dev_unplug" Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 128/311] iio: imu: bno055: fix BNO055_SCAN_CH_COUNT off by one Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 129/311] gpiolib: clear requested flag if line is invalid Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 130/311] interconnect: qcom: sm8450: Fix NULL pointer dereference in icc_link_nodes() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 131/311] gpio: shared: call gpio_chip::of_xlate() if set Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 132/311] gpio: shared: handle pins shared by child nodes of devices Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 133/311] gpio: qixis-fpga: Fix error handling for devm_regmap_init_mmio() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 134/311] drm/bridge: Fix refcount shown via debugfs for encoder_bridges_show() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 135/311] accel/qaic: Handle DBC deactivation if the owner went away Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 136/311] io_uring/rsrc: reject zero-length fixed buffer import Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 137/311] hwmon: (tps53679) Fix array access with zero-length block read Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 138/311] hwmon: (pxe1610) Check return value of page-select write in probe Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 139/311] hwmon: (ltc4286) Add missing MODULE_IMPORT_NS("PMBUS") Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 140/311] gpio: shared: shorten the critical section in gpiochip_setup_shared() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 141/311] dt-bindings: gpio: fix microchip #interrupt-cells Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 142/311] spi: stm32-ospi: Fix resource leak in remove() callback Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 143/311] spi: stm32-ospi: Fix reset control leak on probe error Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 144/311] drm/xe/xe_pagefault: Disallow writes to read-only VMAs Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 145/311] drm/xe/pxp: Clean up termination status on failure Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 146/311] drm/xe/pxp: Remove incorrect handling of impossible state during suspend Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 147/311] drm/xe/pxp: Clear restart flag in pxp_start after jumping back Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 148/311] hwmon: (tps53679) Fix device ID comparison and printing in tps53676_identify() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 149/311] spi: amlogic: spifc-a4: unregister ECC engine on probe failure and remove() callback Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 150/311] hwmon: (occ) Fix missing newline in occ_show_extended() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 151/311] irqchip/riscv-aplic: Restrict genpd notifier to device tree only Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 152/311] drm/sysfb: Fix efidrm error handling and memory type mismatch Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 153/311] hwmon: (asus-ec-sensors) Fix T_Sensor for PRIME X670E-PRO WIFI Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 154/311] mips: ralink: update CPU clock index Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 155/311] sched/fair: Fix zero_vruntime tracking fix Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 156/311] sched/debug: Fix avg_vruntime() usage Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 157/311] perf/x86: Fix potential bad container_of in intel_pmu_hw_config Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 158/311] riscv: kgdb: fix several debug register assignment bugs Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 159/311] riscv: Reset pmm when PR_TAGGED_ADDR_ENABLE is not set Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 160/311] ACPI: RIMT: Add dependency between iommu and devices Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 161/311] drm/ioc32: stop speculation on the drm_compat_ioctl path Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 162/311] rust_binder: use AssertSync for BINDER_VM_OPS Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 163/311] wifi: wilc1000: fix u8 overflow in SSID scan buffer size calculation Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 164/311] wifi: iwlwifi: mvm: fix potential out-of-bounds read in iwl_mvm_nd_match_info_handler() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 165/311] USB: serial: option: add MeiG Smart SRM825WN Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 166/311] drm/amd/display: Fix NULL pointer dereference in dcn401_init_hw() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 167/311] sched_ext: Fix inconsistent NUMA node lookup in scx_select_cpu_dfl() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 168/311] lib/crypto: chacha: Zeroize permuted_state before it leaves scope Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 169/311] sched_ext: Fix SCX_KICK_WAIT deadlock by deferring wait to balance callback Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 170/311] ALSA: caiaq: fix stack out-of-bounds read in init_card Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 171/311] ALSA: ctxfi: Check the error for index mapping Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 172/311] ALSA: ctxfi: Fix missing SPDIFI1 index handling Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 173/311] ALSA: ctxfi: Dont enumerate SPDIF1 at DAIO initialization Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 174/311] ALSA: hda/realtek: add quirk for Acer Swift SFG14-73 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 175/311] ALSA: hda/realtek: Add quirk for ASUS ROG Strix SCAR 15 Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 176/311] ALSA: hda/realtek: add quirk for HP Victus 15-fb0xxx Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 177/311] ALSA: hda/realtek: change quirk for HP OmniBook 7 Laptop 16-bh0xxx Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 178/311] io_uring/net: fix slab-out-of-bounds read in io_bundle_nbufs() Greg Kroah-Hartman
2026-04-08 18:02 ` [PATCH 6.19 179/311] Bluetooth: SMP: derive legacy responder STK authentication from MITM state Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 180/311] Bluetooth: SMP: force responder MITM requirements before building the pairing response Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 181/311] Bluetooth: hci_sync: fix stack buffer overflow in hci_le_big_create_sync Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 182/311] Bluetooth: hci_event: move wake reason storage into validated event handlers Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 183/311] ksmbd: fix OOB write in QUERY_INFO for compound requests Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 184/311] MIPS: SiByte: Bring back cache initialisation Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 185/311] MIPS: Fix the GCC version check for `__multi3 workaround Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 186/311] hwmon: (occ) Fix division by zero in occ_show_power_1() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 187/311] mips: mm: Allocate tlb_vpn array atomically Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 188/311] x86/kexec: Disable KCOV instrumentation after load_segments() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 189/311] drm/amdgpu: fix the idr allocation flags Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 190/311] gpib: fix use-after-free in IO ioctl handlers Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 191/311] iio: add IIO_DECLARE_QUATERNION() macro Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 192/311] iio: orientation: hid-sensor-rotation: fix quaternion alignment Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 193/311] iio: orientation: hid-sensor-rotation: add timestamp hack to not break userspace Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 194/311] iio: adc: ti-adc161s626: fix buffer read on big-endian Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 195/311] iio: adc: ti-adc161s626: use DMA-safe memory for spi_read() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 196/311] iio: adc: ti-ads1119: Fix unbalanced pm reference count in ds1119_single_conversion() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 197/311] iio: adc: ti-ads1119: Reinit completion before wait_for_completion_timeout() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 198/311] iio: adc: ti-ads1119: Replace IRQF_ONESHOT with IRQF_NO_THREAD Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 199/311] drm/ast: dp501: Fix initialization of SCU2C Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 200/311] drm/i915/dsi: Dont do DSC horizontal timing adjustments in command mode Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 201/311] drm/i915/dp: Use crtc_state->enhanced_framing properly on ivb/hsw CPU eDP Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 202/311] drm/i915/cdclk: Do the full CDCLK dance for min_voltage_level changes Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 203/311] drm/amdgpu: Fix wait after reset sequence in S4 Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 204/311] drm/amdgpu: validate doorbell_offset in user queue creation Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 205/311] drm/amdgpu: Change AMDGPU_VA_RESERVED_TRAP_SIZE to 64KB Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 206/311] drm/amdgpu/pm: drop SMU driver if version not matched messages Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 207/311] USB: serial: io_edgeport: add support for Blackbox IC135A Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 208/311] USB: serial: option: add support for Rolling Wireless RW135R-GL Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 209/311] USB: core: add NO_LPM quirk for Razer Kiyo Pro webcam Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 210/311] Input: synaptics-rmi4 - fix a locking bug in an error path Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 211/311] Input: i8042 - add TUXEDO InfinityBook Max 16 Gen10 AMD to i8042 quirk table Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 212/311] Input: bcm5974 - recover from failed mode switch Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 213/311] Input: xpad - add support for BETOP BTP-KP50B/C controllers wireless mode Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 214/311] Input: xpad - add support for Razer Wolverine V3 Pro Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 215/311] iio: adc: ti-ads7950: normalize return value of gpio_get Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 216/311] iio: adc: ti-ads7950: do not clobber gpio state in ti_ads7950_get() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 217/311] iio: adc: ade9000: fix wrong return type in streaming push Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 218/311] iio: adc: ade9000: fix wrong register in CALIBBIAS case for active power Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 219/311] iio: adc: ade9000: move mutex init before IRQ registration Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 220/311] iio: adc: aspeed: clear reference voltage bits before configuring vref Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 221/311] iio: accel: fix ADXL355 temperature signature value Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 222/311] iio: accel: adxl380: fix FIFO watermark bit 8 always written as 0 Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 223/311] iio: accel: adxl313: add missing error check in predisable Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 224/311] iio: dac: ad5770r: fix error return in ad5770r_read_raw() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 225/311] iio: imu: adis16550: fix swapped gyro/accel filter functions Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 226/311] iio: light: vcnl4035: fix scan buffer on big-endian Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 227/311] iio: light: veml6070: fix veml6070_read() return value Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 228/311] iio: imu: bmi160: Remove potential undefined behavior in bmi160_config_pin() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 229/311] iio: imu: st_lsm6dsx: Set FIFO ODR for accelerometer and gyroscope only Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 230/311] iio: imu: st_lsm6dsx: Set buffer sampling frequency for accelerometer only Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 231/311] iio: gyro: mpu3050: Fix incorrect free_irq() variable Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 232/311] iio: gyro: mpu3050: Fix irq resource leak Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 233/311] iio: gyro: mpu3050: Move iio_device_register() to correct location Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 234/311] iio: gyro: mpu3050: Fix out-of-sequence free_irq() Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 235/311] mei: me: reduce the scope on unexpected reset Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 236/311] gpib: lpvo_usb: fix memory leak on disconnect Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 237/311] usb: quirks: add DELAY_INIT quirk for another Silicon Motion flash drive Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 238/311] usb: ulpi: fix double free in ulpi_register_interface() error path Greg Kroah-Hartman
2026-04-08 18:03 ` [PATCH 6.19 239/311] usb: usbtmc: Flush anchored URBs in usbtmc_release Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 240/311] usb: misc: usbio: Fix URB memory leak on submit failure Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 241/311] usb: host: xhci-sideband: delegate offload_usage tracking to class drivers Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 242/311] usb: ehci-brcm: fix sleep during atomic Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 243/311] usb: dwc2: gadget: Fix spin_lock/unlock mismatch in dwc2_hsotg_udc_stop() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 244/311] usb: core: phy: avoid double use of usb3-phy Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 245/311] usb: cdns3: gadget: fix NULL pointer dereference in ep_queue Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 246/311] usb: cdns3: gadget: fix state inconsistency on gadget init failure Greg Kroah-Hartman
2026-04-08 18:04 ` Greg Kroah-Hartman [this message]
2026-04-08 18:04 ` [PATCH 6.19 248/311] x86/platform/geode: Fix on-stack property data use-after-return bug Greg Kroah-Hartman
2026-04-09  8:09   ` Jiri Slaby
2026-04-08 18:04 ` [PATCH 6.19 249/311] io_uring: protect remaining lockless ctx->rings accesses with RCU Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 250/311] auxdisplay: line-display: fix NULL dereference in linedisp_release Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 251/311] bridge: br_nd_send: validate ND option lengths Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 252/311] cdc-acm: new quirk for EPSON HMD Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 253/311] comedi: dt2815: add hardware detection to prevent crash Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 254/311] comedi: runflags cannot determine whether to reclaim chanlist Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 255/311] comedi: Reinit dev->spinlock between attachments to low-level drivers Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 256/311] comedi: ni_atmio16d: Fix invalid clean-up after failed attach Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 257/311] comedi: me_daq: Fix potential overrun of firmware buffer Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 258/311] comedi: me4000: " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 259/311] firmware: microchip: fail auto-update probe if no flash found Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 260/311] dt-bindings: connector: add pd-disable dependency Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 261/311] spi: cadence-qspi: Fix exec_mem_op error handling Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 262/311] s390/zcrypt: Fix memory leak with CCA cards used as accelerator Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 263/311] s390/cpum_sf: Cap sampling rate to prevent lsctl exception Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 264/311] reset: gpio: fix double free in reset_add_gpio_aux_device() error path Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 265/311] PM: EM: Fix NULL pointer dereference when perf domain ID is not found Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 266/311] nvmem: imx: assign nvmem_cell_info::raw_len Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 267/311] nvmem: zynqmp_nvmem: Fix buffer size in DMA and memcpy Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 268/311] netfilter: ipset: drop logically empty buckets in mtype_del Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 269/311] gpib: Fix fluke driver s390 compile issue Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 270/311] vt: discard stale unicode buffer on alt screen exit after resize Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 271/311] vt: resize saved " Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 272/311] counter: rz-mtu3-cnt: prevent counter from being toggled multiple times Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 273/311] counter: rz-mtu3-cnt: do not use struct rz_mtu3_channels dev member Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 274/311] crypto: tegra - Add missing CRYPTO_ALG_ASYNC Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 275/311] vxlan: validate ND option lengths in vxlan_na_create Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 276/311] net: ftgmac100: fix ring allocation unwind on open failure Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 277/311] net: ethernet: mtk_ppe: avoid NULL deref when gmac0 is disabled Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 278/311] iommupt: Fix short gather if the unmap goes into a large mapping Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 279/311] virtio_net: clamp rss_max_key_size to NETDEV_RSS_KEY_LEN Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 280/311] cpufreq: governor: fix double free in cpufreq_dbs_governor_init() error path Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 281/311] sched_ext: Fix is_bpf_migration_disabled() false negative on non-PREEMPT_RCU Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 282/311] sched_ext: Fix stale direct dispatch state in ddsp_dsq_id Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 283/311] gpio: mxc: map Both Edge pad wakeup to Rising Edge Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 284/311] gpio: Fix resource leaks on errors in gpiochip_add_data_with_key() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 285/311] thermal: core: Address thermal zone removal races with resume Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 286/311] thermal: core: Fix thermal zone device registration error path Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 287/311] misc: fastrpc: possible double-free of cctx->remote_heap Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 288/311] misc: fastrpc: check qcom_scm_assign_mem() return in rpmsg_probe Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 289/311] usb: typec: thunderbolt: Set enter_vdo during initialization Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 290/311] thunderbolt: Fix property read in nhi_wake_supported() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 291/311] USB: dummy-hcd: Fix locking/synchronization error Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 292/311] USB: dummy-hcd: Fix interrupt synchronization error Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 293/311] usb: gadget: dummy_hcd: fix premature URB completion when ZLP follows partial transfer Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 294/311] usb: typec: ucsi: validate connector number in ucsi_notify_common() Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 295/311] HID: appletb-kbd: add .resume method in PM Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 296/311] usb: gadget: u_ether: Fix race between gether_disconnect and eth_stop Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 297/311] usb: gadget: u_ether: Fix NULL pointer deref in eth_get_drvinfo Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 298/311] usb: gadget: uvc: fix NULL pointer dereference during unbind race Greg Kroah-Hartman
2026-04-08 18:04 ` [PATCH 6.19 299/311] usb: gadget: f_subset: Fix unbalanced refcnt in geth_free Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 300/311] usb: gadget: f_rndis: Protect RNDIS options with mutex Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 301/311] usb: gadget: f_ecm: Fix net_device lifecycle with device_move Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 302/311] usb: gadget: f_eem: " Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 303/311] usb: gadget: f_subset: " Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 304/311] usb: gadget: f_rndis: " Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 305/311] usb: gadget: f_hid: move list and spinlock inits from bind to alloc Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 306/311] usb: gadget: f_uac1_legacy: validate control request size Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 307/311] kallsyms: clean up @namebuf initialization in kallsyms_lookup_buildid() Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 308/311] kallsyms: clean up modname and modbuildid " Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 309/311] kallsyms: cleanup code for appending the module buildid Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 310/311] kallsyms: prevent module removal when printing module name and buildid Greg Kroah-Hartman
2026-04-08 18:05 ` [PATCH 6.19 311/311] wifi: virt_wifi: remove SET_NETDEV_DEV to avoid use-after-free Greg Kroah-Hartman
2026-04-08 19:41 ` [PATCH 6.19 000/311] 6.19.12-rc1 review Ronald Warsow
2026-04-08 21:06 ` Dileep malepu
2026-04-09  6:15 ` Shung-Hsi Yu
2026-04-09  7:20   ` Luna Jernberg
2026-04-09  7:22 ` Pavel Machek
2026-04-09  8:03 ` Ron Economos

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260408175948.614635883@linuxfoundation.org \
    --to=gregkh@linuxfoundation.org \
    --cc=guanyulin@google.com \
    --cc=hailong.liu@oppo.com \
    --cc=mathias.nyman@linux.intel.com \
    --cc=patches@lists.linux.dev \
    --cc=stable@kernel.org \
    --cc=stable@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
--- a/drivers/usb/core/offload.c
+++ b/drivers/usb/core/offload.c
@@ -25,33 +25,30 @@
  */
 int usb_offload_get(struct usb_device *udev)
 {
-	int ret;
+	int ret = 0;
 
-	usb_lock_device(udev);
-	if (udev->state == USB_STATE_NOTATTACHED) {
-		usb_unlock_device(udev);
+	if (!usb_get_dev(udev))
 		return -ENODEV;
-	}
 
-	if (udev->state == USB_STATE_SUSPENDED ||
-		   udev->offload_at_suspend) {
-		usb_unlock_device(udev);
-		return -EBUSY;
+	if (pm_runtime_get_if_active(&udev->dev) != 1) {
+		ret = -EBUSY;
+		goto err_rpm;
 	}
 
-	/*
-	 * offload_usage could only be modified when the device is active, since
-	 * it will alter the suspend flow of the device.
-	 */
-	ret = usb_autoresume_device(udev);
-	if (ret < 0) {
-		usb_unlock_device(udev);
-		return ret;
+	spin_lock(&udev->offload_lock);
+
+	if (udev->offload_pm_locked) {
+		ret = -EAGAIN;
+		goto err;
 	}
 
 	udev->offload_usage++;
-	usb_autosuspend_device(udev);
-	usb_unlock_device(udev);
+
+err:
+	spin_unlock(&udev->offload_lock);
+	pm_runtime_put_autosuspend(&udev->dev);
+err_rpm:
+	usb_put_dev(udev);
 
 	return ret;
 }
@@ -69,35 +66,32 @@ EXPORT_SYMBOL_GPL(usb_offload_get);
  */
 int usb_offload_put(struct usb_device *udev)
 {
-	int ret;
+	int ret = 0;
 
-	usb_lock_device(udev);
-	if (udev->state == USB_STATE_NOTATTACHED) {
-		usb_unlock_device(udev);
+	if (!usb_get_dev(udev))
 		return -ENODEV;
-	}
 
-	if (udev->state == USB_STATE_SUSPENDED ||
-		   udev->offload_at_suspend) {
-		usb_unlock_device(udev);
-		return -EBUSY;
+	if (pm_runtime_get_if_active(&udev->dev) != 1) {
+		ret = -EBUSY;
+		goto err_rpm;
 	}
 
-	/*
-	 * offload_usage could only be modified when the device is active, since
-	 * it will alter the suspend flow of the device.
-	 */
-	ret = usb_autoresume_device(udev);
-	if (ret < 0) {
-		usb_unlock_device(udev);
-		return ret;
+	spin_lock(&udev->offload_lock);
+
+	if (udev->offload_pm_locked) {
+		ret = -EAGAIN;
+		goto err;
 	}
 
 	/* Drop the count when it wasn't 0, ignore the operation otherwise. */
 	if (udev->offload_usage)
 		udev->offload_usage--;
-	usb_autosuspend_device(udev);
-	usb_unlock_device(udev);
+
+err:
+	spin_unlock(&udev->offload_lock);
+	pm_runtime_put_autosuspend(&udev->dev);
+err_rpm:
+	usb_put_dev(udev);
 
 	return ret;
 }
@@ -112,25 +106,47 @@ EXPORT_SYMBOL_GPL(usb_offload_put);
  * management.
  *
  * The caller must hold @udev's device lock. In addition, the caller should
  * ensure downstream usb devices are all either suspended or marked as
  * "offload_at_suspend" to ensure the correctness of the return value.
  *
  * Returns true on any offload activity, false otherwise.
  */
 bool usb_offload_check(struct usb_device *udev) __must_hold(&udev->dev->mutex)
 {
 	struct usb_device *child;
-	bool active;
+	bool active = false;
 	int port1;
 
+	if (udev->offload_usage)
+		return true;
+
 	usb_hub_for_each_child(udev, port1, child) {
 		usb_lock_device(child);
 		active = usb_offload_check(child);
 		usb_unlock_device(child);
+
 		if (active)
-			return true;
+			break;
 	}
 
-	return !!udev->offload_usage;
+	return active;
 }
 EXPORT_SYMBOL_GPL(usb_offload_check);
+
+/**
+ * usb_offload_set_pm_locked - set the PM lock state of a USB device
+ * @udev: the USB device to modify
+ * @locked: the new lock state
+ *
+ * Setting @locked to true prevents offload_usage from being modified. This
+ * ensures that offload activities cannot be started or stopped during critical
+ * power management transitions, maintaining a stable state for the duration
+ * of the transition.
+ */
+void usb_offload_set_pm_locked(struct usb_device *udev, bool locked)
+{
+	spin_lock(&udev->offload_lock);
+	udev->offload_pm_locked = locked;
+	spin_unlock(&udev->offload_lock);
+}
+EXPORT_SYMBOL_GPL(usb_offload_set_pm_locked);
@@ -112,25 +106,47 @@ EXPORT_SYMBOL_GPL(usb_offload_put);
  *
  * The caller must hold @udev's device lock. In addition, the caller should
- * ensure downstream usb devices are all either suspended or marked as
- * "offload_at_suspend" to ensure the correctness of the return value.
+ * ensure the device itself and the downstream usb devices are all marked as
+ * "offload_pm_locked" to ensure the correctness of the return value.
  *
  * Returns true on any offload activity, false otherwise.